@@ -3,11 +3,12 @@
 from __future__ import annotations
 from enum import Enum
 from typing import List, Tuple
-from ladybug.datacollection import HourlyContinuousCollection, \
-    HourlyDiscontinuousCollection, BaseCollection
+from ladybug.datacollection import HourlyContinuousCollection, HourlyDiscontinuousCollection
 from ladybug.color import Color, Colorset
-from ladybug.analysisperiod import AnalysisPeriod
 from ladybug.header import Header
+from ladybug.analysisperiod import AnalysisPeriod
+from ladybug_geometry.geometry2d import Mesh2D
+from ladybug_geometry.geometry2d.pointvector import Point2D
 
 
 def discontinuous_to_continuous(
@@ -98,3 +99,51 @@ color_set = {
     'thermal_comfort': Colorset.thermal_comfort(),
     'view_study': Colorset.view_study()
 }
+
+
+def mesh_to_coordinates(mesh: Mesh2D) -> List[List[List[float], List[float]]]:
+    """Convert vertices of Ladybug 2D mesh to coordinates that Plotly can use.
+
+    Args:
+        mesh: Ladybug 2D mesh.
+
+    Returns:
+        A list of lists of coordinates where each list has two lists. The first has 
+        x coordinates and the second has y coordinates.
+    """
+    cords = []
+    for face in mesh.faces:
+        x_cords = []
+        y_cords = []
+        for vert in face:
+            x_cords.append(mesh.vertices[vert].x)
+            y_cords.append(mesh.vertices[vert].y)
+        # Add first cordinate to the end to close the polygon
+        x_cords.append(x_cords[0])
+        y_cords.append(y_cords[0])
+        cords.append([x_cords, y_cords])
+
+    return cords
+
+
+def verts_to_coordinates(points: List[Point2D]) -> Tuple[List[float], List[float]]:
+    """Convert a list of Ladybug Point2Ds to coordinates that Plotly can use.
+
+    Args:
+        points: A list of Ladybug Point2Ds.
+
+    Returns:
+        A tuple of two items
+
+        -   A list of x coordinates.
+        -   A list of y coordinates.
+    """
+    x_cords, y_cords = [], []
+    for point in points:
+
+        x_cords.append(point.x)
+        y_cords.append(point.y)
+
+    x_cords.append(x_cords[0])
+    y_cords.append(y_cords[0])
+    return x_cords, y_cords
