@@ -1,6 +1,7 @@
 """Create plotly figures from pandas Dataframe."""
 
 
+from ladybug_geometry.geometry2d.pointvector import Point2D
 import numpy as np
 import pandas as pd
 
@@ -16,10 +17,13 @@ from plotly.graph_objects import Bar
 from plotly.subplots import make_subplots
 
 from ._to_dataframe import dataframe, Frequency, MONTHS
-from ._helper import discontinuous_to_continuous, rgb_to_hex, ColorSet, color_set
+from ._helper import discontinuous_to_continuous, rgb_to_hex, ColorSet, color_set,\
+    mesh_to_coordinates
+from ._psych import _psych_chart
+from .utils import Strategy, StrategyParameters
 
 from ladybug.datacollection import HourlyContinuousCollection, \
-    HourlyDiscontinuousCollection, MonthlyCollection, DailyCollection
+    HourlyDiscontinuousCollection, MonthlyCollection, DailyCollection, BaseCollection
 from ladybug.windrose import WindRose
 from ladybug.color import Color
 from ladybug_pandas.series import Series
@@ -27,6 +31,8 @@ from ladybug import psychrometrics as psy
 from ladybug.sunpath import Sunpath
 from ladybug.psychchart import PsychrometricChart
 from ladybug.dt import DateTime
+from ladybug_comfort.chart.polygonpmv import PolygonPMV
+
 
 # set white background in all charts
 pio.templates.default = 'plotly_white'
@@ -689,208 +695,36 @@ def wind_rose(wind_rose: WindRose, title: str = 'Wind Rose', legend: bool = True
     return fig
 
 
-def _humidity_ratio(dbt: float, rh: float) -> float:
-    if dbt == None or rh == None:
-        return 0.0
-    return psy.humid_ratio_from_db_rh(dbt, rh)
-
-
-def psych_chart(psych: PsychrometricChart,
-                data: Union[HourlyContinuousCollection,
-                            HourlyDiscontinuousCollection] = None,
-                colorset: ColorSet = ColorSet.original, title: str = None) -> Figure:
+def psych_chart(psych: PsychrometricChart, data: BaseCollection = None,
+                title: str = None, polygon_pmv: PolygonPMV = None,
+                strategies: List[Strategy] = None,
+                strategy_parameters: StrategyParameters = StrategyParameters(),
+                solar_data: HourlyContinuousCollection = None) -> Figure:
     """Create a psychrometric chart.
 
     Args:
         psych: A ladybug PsychrometricChart object.
-        data: A ladybug HourlyDataCollection object.
-        colorset: A Colorset object. Defaults to ColorSet.original which will use
-            Ladybug's original colorset.
+        data: A ladybug DataCollection object.
         title: A title for the plot. Defaults to None.
+        polygon_pmv: A ladybug PolygonPMV object. If provided, polygons will be drawn.
+            Defaults to None.
+        strategies: A list of strategies to be applied to the chart. Accepts a list of
+            Stragegy objects. Defaults to out of the box StrategyParameters object.
+        strategy_parameters: A StrategyParameters object. Defaults to None.
+        solar_data: An annual hourly continuous data collection of irradiance
+            (or radiation) in W/m2 (or Wh/m2) that aligns with the data
+            points on the psychrometric chart. This is only required when
+            plotting a "Passive Solar Heating" strategy polygon on the chart.
+            The irradiance values should be incident on the orientation of
+            the passive solar heated windows. So using global horizontal
+            radiation assumes that all windows are skylights (like a
+            greenhouse). Defaults to None.
 
     Returns:
         A plotly figure.
     """
-
-    # get dbt and rh from the psychrometric chart
-    dbt = psych.temperature
-    rh = psych.relative_humidity
-
-    # We're not supporting Daily data for now
-    assert not isinstance(dbt, DailyCollection), 'Ladybug PsychrometricChart created'\
-        ' using DailyCollection is not supported.'
-
-    # make sure all data collections are aligned
-    if data:
-        if isinstance(data, HourlyDiscontinuousCollection):
-            assert HourlyDiscontinuousCollection.are_collections_aligned([data, dbt, rh]),\
-                'HourlyDiscontinuousCollection objects are not aligned.'
-        elif isinstance(data, HourlyContinuousCollection):
-            assert HourlyContinuousCollection.are_collections_aligned([data, dbt, rh]),\
-                'HourlyContinuousCollection objects are not aligned.'
-        else:
-            raise ValueError(f'{type(data)} object is not supported.')
-
-    # Convert Discontinuous data to Continuous data
-    if isinstance(dbt, HourlyDiscontinuousCollection):
-        if data:
-            data = discontinuous_to_continuous(data)
-        dbt = discontinuous_to_continuous(dbt)
-        rh = discontinuous_to_continuous(rh)
-
-    # creating dataframe
-    df = dataframe()
-    df['DBT'] = Series(dbt).values
-    df['RH'] = Series(rh).values
-    df['hr'] = np.vectorize(_humidity_ratio)(dbt.values, rh.values)
-
-    # Set maximum and minimum according to data
-    data_max = 5 * ceil(df["DBT"].max() / 5)
-    data_min = 5 * floor(df["DBT"].min() / 5)
-    var_range_x = [data_min, data_max]
-
-    data_max = (5 * ceil(df["hr"].max() * 1000 / 5)) / 1000
-    data_min = (5 * floor(df["hr"].min() * 1000 / 5)) / 1000
-    var_range_y = [data_min, data_max]
-
-    dbt_list = list(range(-60, 60, 1))
-    rh_list = list(range(10, 110, 10))
-
-    rh_df = pd.DataFrame()
-    for rh_item in rh_list:
-        hr_list = np.vectorize(psy.humid_ratio_from_db_rh)(dbt_list, rh_item)
-        name = "rh" + str(rh_item)
-        rh_df[name] = hr_list
-
-    fig = go.Figure()
-
-    # Add curved lines for humidity
-    for rh_item in rh_list:
-        name = "rh" + str(rh_item)
-        fig.add_trace(
-            go.Scatter(
-                x=dbt_list,
-                y=rh_df[name],
-                showlegend=False,
-                mode="lines",
-                name="",
-                hovertemplate="RH " + str(rh_item) + "%",
-                line=dict(width=1, color="#85837f"),
-            )
-        )
-
-    # if no data is provided, plot frequency
-    if not data:
-        # add count column that is used to plot frequency as count
-        df['text'] = df['DBT'].astype(str) + df['hr'].astype(str)
-        df['count'] = [df['text'].value_counts()[val] for val in df['text'].values]
-
-        fig.add_trace(
-            go.Scatter(
-                x=df["DBT"],
-                y=df["hr"],
-                showlegend=False,
-                mode="markers",
-                marker=dict(
-                    size=7,
-                    color=df['count'],
-                    showscale=True,
-                    opacity=1,
-                    colorscale=[rgb_to_hex(color)
-                                for color in color_set[colorset.value]],
-                    colorbar=dict(thickness=30, title='Hours' + '<br>  '),
-                ),
-                customdata=np.stack((df['RH'], df['count']), axis=-1),
-                hovertemplate='Dry bulb temperature'
-                + ": %{x}"
-                + ' C'
-                + "<br>"
-                + 'Relative humidity'
-                + ": %{customdata[0]}"
-                + ' %'
-                + "<br>"
-                + 'Humidity ratio'
-                + ": %{y: .2f}"
-                + ' Kg water / Kg air'
-                + "<br>"
-                + 'Hours in a year'
-                + ": %{customdata[1]}"
-            )
-        )
-
-        title = title if title else 'Psychrometric Chart - Frequency'
-
-    # plot the data
-    else:
-        var = data.header.data_type.name
-        var_unit = data.header.unit
-        df[var] = Series(data).values
-
-        fig.add_trace(
-            go.Scatter(
-                x=df["DBT"],
-                y=df["hr"],
-                showlegend=False,
-                mode="markers",
-                marker=dict(
-                    size=7,
-                    color=df[var],
-                    showscale=True,
-                    opacity=1,
-                    colorscale=[rgb_to_hex(color)
-                                for color in color_set[colorset.value]],
-                    colorbar=dict(thickness=30, title=var_unit + "<br>  "),
-                ),
-                customdata=np.stack((df['RH'], df[var]), axis=-1),
-                hovertemplate='Dry bulb temperature'
-                + ": %{x}"
-                + ' C'
-                + "<br>"
-                + 'Relative humidity'
-                + ": %{customdata[0]}"
-                + ' %'
-                + "<br>"
-                + 'Humidity ratio'
-                + ": %{y: .2f}"
-                + ' Kg water / Kg air'
-                + "<br>"
-                + var
-                + ": %{customdata[1]}"
-                + ' ' + var_unit,
-                name="",
-            )
-        )
-
-        title = title if title else f'Psychrometric Chart - {var}'
-
-    fig.update_layout(
-        template='plotly_white',
-        margin=dict(l=20, r=20, t=33, b=20),
-        title={
-            'text': title,
-            'y': 1,
-            'x': 0.5,
-            'xanchor': 'center',
-            'yanchor': 'top'
-        })
-
-    fig.update_xaxes(
-        title_text='Temperature (°C)',
-        range=var_range_x,
-        showline=True,
-        linewidth=1,
-        linecolor='black',
-        mirror=True,
-    )
-    fig.update_yaxes(
-        title_text='Humidity Ratio (KG water/KG air)',
-        range=var_range_y,
-        showline=True,
-        linewidth=1,
-        linecolor='black',
-        mirror=True,
-    )
-    return fig
+    return _psych_chart(psych, data, title, polygon_pmv, strategies,
+                        strategy_parameters, solar_data)
 
 
 def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
@@ -925,8 +759,8 @@ def sunpath(sunpath: Sunpath, data: HourlyContinuousCollection = None,
     df['azimuth'] = azimuths
 
     if data:
-        assert isinstance(data, HourlyContinuousCollection), 'data must be an'\
-            f' HourlyContinuousCollection. Instead got {type(data)}.'
+        assert isinstance(data, HourlyContinuousCollection), 'data must be an'
+        f' HourlyContinuousCollection. Instead got {type(data)}.'
 
         var_name = data.header.data_type.name
         var_unit = data.header.unit
